@@ -2,8 +2,6 @@
  * acconfig.h
  *
  * Additional autoconf defines for this program.
- *
- * $Id: acconfig.h,v 1.4 2004/04/22 10:48:16 quozl Exp $
  */
 
 /* Use BSD User land PPP? */
@@ -12,9 +10,6 @@
 /* Use SLIRP? */
 #undef SLIRP
 
-/* Let PPPD choose the IP addresses? */
-#undef PPPD_IP_ALLOC
-
 /* Enable Broadcast Relay? */
 #undef BCRELAY
 
@@ -27,6 +22,9 @@
 /* Where is my pppd? */
 #undef PPP_BINARY
 
+/* Syslog Facility to use?  See openlog(3). */
+#undef PPTP_FACILITY
+
 /* Have libwrap? */
 #undef HAVE_LIBWRAP
 
