@@ -2,8 +2,6 @@
  * compat.c
  *
  * Compatibility functions for different OSes
- *
- * $Id: compat.c,v 1.5 2005/01/05 11:01:51 quozl Exp $
  */
 
 #if HAVE_CONFIG_H
@@ -11,6 +9,7 @@
 #endif
 
 #include "compat.h"
+#include "our_syslog.h"
 
 #ifndef HAVE_STRLCPY
 #include <string.h>
@@ -18,16 +17,16 @@
 
 void strlcpy(char *dst, const char *src, size_t size)
 {
-	strncpy(dst, src, size - 1);
-	dst[size - 1] = '\0';
+        strncpy(dst, src, size - 1);
+        dst[size - 1] = '\0';
 }
 #endif
 
 #ifndef HAVE_MEMMOVE
 void *memmove(void *dst, const void *src, size_t size)
 {
-	bcopy(src, dst, size);
-	return dst;
+        bcopy(src, dst, size);
+        return dst;
 }
 #endif
 
@@ -57,49 +56,49 @@ void *memmove(void *dst, const void *src, size_t size)
 
 int openpty(int *master, int *slave, char *name, void *unused1, void *unused2)
 {
-	int devindex = 0, letter = 0;
-	int fd1, fd2;
-	char ttydev[PTYMAX], ptydev[TTYMAX];
+        int devindex = 0, letter = 0;
+        int fd1, fd2;
+        char ttydev[PTYMAX], ptydev[TTYMAX];
 
-	syslog(LOG_DEBUG, "CTRL: Allocating pty/tty pair");
-	strcpy(ttydev, TTYDEV);
-	strcpy(ptydev, PTYDEV);
-	while (PTYCHAR1[letter]) {
-		ttydev[TTYMAX - 3] = ptydev[PTYMAX - 3] = PTYCHAR1[letter];
-		while (PTYCHAR2[devindex]) {
-			ttydev[TTYMAX - 2] = ptydev[PTYMAX - 2] = PTYCHAR2[devindex];
-			if ((fd1 = open(ptydev, O_RDWR)) >= 0) {
-				if ((fd2 = open(ttydev, O_RDWR)) >= 0) {
-					goto out;
-				} else {
-					close(fd1);
-				}
-			}
-			devindex++;
-		}
-		devindex = 0;
-		letter++;
-	}
-	syslog(LOG_ERR, "CTRL: Failed to allocate pty");
-	return -1;		/* Unable to allocate pty */
+        syslog(LOG_DEBUG, "CTRL: Allocating pty/tty pair");
+        strcpy(ttydev, TTYDEV);
+        strcpy(ptydev, PTYDEV);
+        while (PTYCHAR1[letter]) {
+                ttydev[TTYMAX - 3] = ptydev[PTYMAX - 3] = PTYCHAR1[letter];
+                while (PTYCHAR2[devindex]) {
+                        ttydev[TTYMAX - 2] = ptydev[PTYMAX - 2] = PTYCHAR2[devindex];
+                        if ((fd1 = open(ptydev, O_RDWR)) >= 0) {
+                                if ((fd2 = open(ttydev, O_RDWR)) >= 0) {
+                                        goto out;
+                                } else {
+                                        close(fd1);
+                                }
+                        }
+                        devindex++;
+                }
+                devindex = 0;
+                letter++;
+        }
+        syslog(LOG_ERR, "CTRL: Failed to allocate pty");
+        return -1;              /* Unable to allocate pty */
 
       out:
-	syslog(LOG_INFO, "CTRL: Allocated pty/tty pair (%s,%s)", ptydev, ttydev);
-	if (master)
-		*master = fd1;
-	if (slave)
-		*slave = fd2;
-	if (name)
-		strcpy(name, ttydev);	/* no way to bounds check */
-	return 0;
+        syslog(LOG_INFO, "CTRL: Allocated pty/tty pair (%s,%s)", ptydev, ttydev);
+        if (master)
+                *master = fd1;
+        if (slave)
+                *slave = fd2;
+        if (name)
+                strcpy(name, ttydev);   /* no way to bounds check */
+        return 0;
 }
 #endif
 
 #ifndef HAVE_STRERROR
 char *strerror(int errnum) {
-	static char buf[16];
-	sprintf(buf, "Error %d", errnum);
-	return buf;
+        static char buf[16];
+        sprintf(buf, "Error %d", errnum);
+        return buf;
 }
 #endif
 
@@ -165,19 +164,17 @@ int sigpipe_create()
 /* generic handler for signals, writes signal number to pipe */
 void sigpipe_handler(int signum)
 {
-  write(sigpipe[1], &signum, sizeof(signum));
+  if (write(sigpipe[1], &signum, sizeof(signum)) == -1) {
+    syslog_perror("sigpipe write");
+  }
   signal(signum, sigpipe_handler);
 }
 
 /* assign a signal number to the pipe */
 void sigpipe_assign(int signum)
 {
-  sigset_t sigset;
   struct sigaction sa;
 
-  sigemptyset(&sigset);
-  sigaddset(&sigset, signum);
-  
   memset(&sa, 0, sizeof(sa));
   sa.sa_handler = sigpipe_handler;
   sigaction(signum, &sa, NULL);
@@ -193,7 +190,10 @@ int sigpipe_fd()
 int sigpipe_read()
 {
   int signum;
-  read(sigpipe[0], &signum, sizeof(signum));
+  if (read(sigpipe[0], &signum, sizeof(signum)) == -1) {
+    syslog_perror("sigpipe read");
+    return 0;
+  }
   return signum;
 }
 
